@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -54,7 +54,6 @@ public:
 	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
 	void ExportToGhemical ();
 	void SelectAlignmentItem (Object *child);
-	void Lock (bool LockState) {m_IsLoading = LockState;}
 	string GetAlignmentId () {return (m_Alignment)? m_Alignment->GetId (): "";}
 
 private:
