@@ -4,7 +4,7 @@
  * GChemPaint library
  * text.cc 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -139,11 +139,11 @@ static void gnome_canvas_rich_text_gcp_realize(GnomeCanvasItem *item)
 
 static gint gnome_canvas_rich_text_gcp_event(GnomeCanvasItem *item, GdkEvent *event)
 {
-	GnomeCanvasRichTextExt *text = GNOME_CANVAS_RICH_TEXT_EXT(item);
 	gcpText* pText = (gcpText*)g_object_get_data(G_OBJECT(item), "object");
 	if (pText)
 		if (!pText->OnEvent(event))
-			(* GNOME_CANVAS_ITEM_CLASS(parent_class)->event)(item, event);
+			return (* GNOME_CANVAS_ITEM_CLASS(parent_class)->event)(item, event);
+	return true;
 }
 
 gcpText::gcpText(): gcpTextObject(TextType)
@@ -228,7 +228,7 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 	{
 		//find the longest included tag
 		TagList0 = TagList;
-		GtkTextTag *tag;
+		GtkTextTag *tag = NULL;
 		while (TagList0)
 		{
 			next = start;
@@ -658,12 +658,22 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
 	GnomeCanvasGroup* group = pData->Items[this];
 	gchar* color;
-	switch (state)
-	{	
-		case SelStateUnselected: color = "white"; break;
-		case SelStateSelected: color = SelectColor; break;
-		case SelStateUpdating: color = AddColor; break;
-		case SelStateErasing: color = DeleteColor; break;
+	switch (state) {	
+		case SelStateUnselected:
+			color = "white";
+			break;
+		case SelStateSelected:
+			color = SelectColor;
+			break;
+		case SelStateUpdating:
+			color = AddColor;
+			break;
+		case SelStateErasing:
+			color = DeleteColor;
+			break;
+		default:
+			color = "white";
+			break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")), "fill_color", color, NULL);
 }
