@@ -308,7 +308,7 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 		pActiveTool->OnDrag(x, y, event->button.state);
 		return true;
 	case GDK_BUTTON_RELEASE:
-	switch (event->button.button)
+		switch (event->button.button)
 		{
 		case 1:
 			if (!m_Dragging) break;
@@ -316,10 +316,15 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 			pActiveTool->OnRelease(x, y, event->button.state);
 			m_pDoc->GetApplication()->ClearStatus();
 			return true;
+		default:
+			break;
 		}
 		break;
+	default:
+		break;
 	}
 	return false;
+	
 }
 
 void gcpView::AddObject(Object* pObject)
@@ -390,6 +395,21 @@ GtkWidget* gcpView::CreateNewWidget()
 		{
 			m_PangoContext = gtk_widget_create_pango_context(m_pWidget);
 			g_object_ref(G_OBJECT(m_PangoContext));
+			// bad hack to get charge sign size.
+			if (ChargeSignSize == 0.) {
+				PangoLayout *pl = pango_layout_new (m_PangoContext);
+				char *markup = g_strdup_printf ("<span font_desc=\"%s\">\xE2\x8a\x95</span>", m_sSmallFontName);
+				pango_layout_set_markup (pl, markup, -1);
+				g_free (markup);
+				PangoLayoutIter* iter = pango_layout_get_iter (pl);
+				PangoRectangle ink, log;
+				pango_layout_iter_get_run_extents (iter, &ink, &log);
+				ChargeYAlign = pango_layout_iter_get_baseline (iter) / PANGO_SCALE;
+				pango_layout_iter_free (iter);
+				g_object_unref (pl);
+				ChargeSignSize = ink.width / PANGO_SCALE;
+				ChargeSignHeight = log.height / PANGO_SCALE;
+			}
 			UpdateFont();
 		}
 	}
@@ -469,8 +489,6 @@ void gcpView::UpdateFont()
 	pl = pango_layout_new(m_PangoContext);
 	pango_layout_set_text(pl, "C", 1);
 	pango_layout_get_extents(pl, &rect, NULL);
-	PangoLayoutIter* iter = pango_layout_get_iter(pl);
-	double ascent = pango_layout_iter_get_baseline(iter) / PANGO_SCALE;
 	m_BaseLineOffset =  (double(rect.height / PANGO_SCALE) / 2.0) / DefaultZoomFactor;
 	g_object_unref(G_OBJECT(pl));
 }
@@ -576,12 +594,10 @@ void gcpView::OnReceive(GtkClipboard* clipboard, GtkSelectionData* selection_dat
 	guint *DataType = (clipboard == gtk_clipboard_get(GDK_SELECTION_CLIPBOARD))? &ClipboardDataType: &ClipboardDataType1;
 	g_return_if_fail((selection_data->target == gdk_atom_intern (targets[*DataType].target, FALSE)));
 	if (pActiveTool->OnReceive(clipboard, selection_data, *DataType)) return;
-//	if (ToolsDlg) ToolsDlg->Select(SelectId);
-	else if (pActiveTool/* && pActiveTool->Activate(false)*/)
+	else if (pActiveTool)
 	{
 		pApp->ActivateTool("Select", true);
 		pActiveTool = pApp->GetActiveTool();
-//		if (pActiveTool) pActiveTool->Activate(true);
 	}
 	if (!pActiveTool || (pActiveTool != pApp->GetTool("Select"))) return;
 	xmlDocPtr xml;
@@ -624,7 +640,7 @@ void gcpView::OnReceive(GtkClipboard* clipboard, GtkSelectionData* selection_dat
 				gtk_text_buffer_get_bounds(buf, &start, &end);
 				gtk_text_buffer_remove_all_tags(buf, &start, &end);
 				gtk_text_buffer_apply_tag_by_name(buf, pApp->GetFontName(), &start, &end);
-				text->OnEndUserAction(buf);
+				text->OnChanged(buf);
 				m_pDoc->AddObject(text);
 				m_pData->SetSelected(text);
 			}
@@ -754,7 +770,6 @@ bool gcpView::OnSize(int width, int height)
 {
 	if ((width == m_width) && (height == m_height)) return true;
 	std::list<GtkWidget*>::iterator i;
-	int x, y;
 	m_height = height;
 	m_width = width;
 	for (i = m_Widgets.begin(); i != m_Widgets.end(); i++)
@@ -897,7 +912,6 @@ void gcpView::ExportImage (const char* filename, const char* type)
 						GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
 						GnomeCanvasBuf cbuf;
 						int i, j, mask, lines, bytes;
-						unsigned char b;
 						cbuf.buf = gdk_pixbuf_get_pixels (pixbuf);
 						cbuf.rect.x0 = (int) floor (rect.x0);
 						cbuf.rect.x1 = (int) ceil (rect.x1);
