@@ -143,7 +143,6 @@ typedef struct
 bool gcpRetrosynthesis::Build (list<Object*>& Children) throw (invalid_argument)
 {
 	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
-	gcpView *pView = pDoc->GetView ();
 	gcpWidgetData  *pData= reinterpret_cast<gcpWidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
 	list<Object*>::iterator i, iend = Children.end ();
 	map<Object *, ObjectData> Objects;
@@ -313,7 +312,7 @@ typedef struct
 
 static void AlignStep (map<Object*, StepData> &data, gcpRetrosynthesisStep *step, gcpView *pView, gcpWidgetData  *pData)
 {
-	double x0, y0, x1, y1, x2, y2, x, y, l, dx, dy;
+	double x0, y0, x1, y1, x, y, l, dx, dy;
 	bool horiz;
 	StepData sd = data[step], sd1;
 	map<gcpRetrosynthesisStep *, gcpRetrosynthesisArrow *> *Arrows = step->GetArrows ();
